#######
History
#######

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

.. :changelog:

2.0.0 (2020-03-29)
==================

- API change: Rename ``use_stringify`` → ``unmutated``.

- License: Release under MIT License.

- DX: Release and CI improvements.

1.0.0 (2020-01-25)
==================

- DX: Release process improvements (no new features).

0.4.0 (2020-01-19)
==================

- First official release (for |dob|_ and |nark|_).

